#
# spec file for package pragha
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pragha
Version:        1.3.99.1
Release:        4.6
Summary:        Lightweight Music Player
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://github.com/pragha-music-player/pragha
Source0:        https://github.com/pragha-music-player/pragha/releases/download/v%{version}/%{name}-%{version}.tar.bz2
Source100:      pragha-rpmlintrc
BuildRequires:  appstream-glib
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  rygel-devel
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(grilo-0.3)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gthread-2.0) >= 2.31
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4.0
BuildRequires:  pkgconfig(gudev-1.0)
%if 0%{?suse_version} > 1500 || (0%{?suse_version} >= 1500 && 0%{?sle_version} > 150500)
BuildRequires:  pkgconfig(gupnp-1.6)
%else
BuildRequires:  pkgconfig(gupnp-1.2)
%endif
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(keybinder-3.0)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_paranoia) >= 0.90
BuildRequires:  pkgconfig(libclastfm) >= 0.5
BuildRequires:  pkgconfig(libglyr)
BuildRequires:  pkgconfig(libmtp)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpeas-1.0)
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxfce4ui-2)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(totem-plparser)
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Recommends:     %{name}-lang
Recommends:     %{name}-plugins

%description
A Lightweight Music Player for GNU/Linux, based on Gtk, sqlite, and
completely written in C, constructed to be fast, light, and
simultaneously complete without obstructing the daily work.

Pragha was originally derived of Consonance Music Manager
(http://sites.google.com/site/consonancemanager/), discontinued by the
original author.

Some of the features are:
* Library management using sqlite3.
* Versatile Amarok-style play queue.
* Multiple views.
* OSD support with Libnotify.
* Id3 tag editing.
* mp3, ogg, flac, modplug, wav, asf, wma, mp4, m4a, MonkeyAudio and
  Audio CD support.
* Last.fm scrobbling, get cover art, get artist information, append
  similar songs, love, unlove, etc.
* Playlist management (M3U Exporting).
* DBUS management interface.
* MPRIS2 Support.
* Search/Filterin the current playlist.
* Search lyrics.

%package plugins
Summary:        Plugins for Pragha
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}

%description plugins
This package includes plugins for the Pragha player.

* AcoustID - Get metadata on AcoustID service.
* Ampache - Append music on Ampache server.
* CD-ROM - Play Audio CDs.
* Devices - Management removable devices.
* DLNA Server - Share your playlist on a DLNA server.
* DLNA Renderer - Play music on a DLNA server.
* Global Hotkeys - Control Pragha with multimedia keys.
* Global Hotkeys with gnome-media-keys daemon - Control Pragha with
  gnome-media-keys daemon.
* Koel - Append music on Koel server.
* Last.fm - Scrobbling, love, unlove song and append similar song to get
  related playlists.
* MPRIS2 - Control Pragha with MPRIS2 interface.
* MTP Devices - Management MTP devices.
* Notification - Show notification when change songs.
* Removable Media - Detect removable media and scan it.
* Song Info - Get Artist info, Lyrics and Album arts of yours songs.
* Get radios - Get radios on TuneIn.

%package plugins-devel
Summary:        Development Files for Pragha Plugins
Group:          Development/Libraries/C and C++
Requires:       pkgconfig(libpeas-1.0)
Requires:       pkgconfig(libpeas-gtk-1.0)

%description plugins-devel
This package contains development files needed to develop plugins for Pragha.

%lang_package

%prep
%setup -q

%build
%if 0%{?sle_version} >= 0150200 || (0%{?suse_version} >= 01550 && 0%{?is_opensuse})
export CPPFLAGS='-I/usr/include/gssdp-1.2/ -I/usr/include/gupnp-1.2/ -I/usr/include/libsoup-2.4/'
%else
export CPPFLAGS='-I/usr/include/gssdp-1.0/ -I/usr/include/gupnp-1.0/ -I/usr/include/libsoup-2.4/'
%endif
%configure
%make_build

%install
%make_install

find %{buildroot}%{_libdir}/%{name}/plugins/ -type f -name "*.la" -delete -print

# Remove installed docs -- I will install them myself.
rm -rf %{buildroot}%{_datadir}/doc/%{name}

# Install Norwegian Bokmål locale to the right place.
mv -f %{buildroot}%{_datadir}/locale/{no,nb}

# Install Korean locale to the right place.
mv -f %{buildroot}%{_datadir}/locale/{ko_KR,ko}

# Install Castillan locale to the right place.
mv -f %{buildroot}%{_datadir}/locale/{ca_ES,ca}

rm -f %{buildroot}%{_libdir}/pragha/libpragha.la

%fdupes -s %{buildroot}%{_datadir}/icons/hicolor/

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.xml

%find_lang %{name}

%files
# FIXME: add AUTHORS to docs if not empty.
%license COPYING
%doc FAQ NEWS README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/*.*
%{_datadir}/metainfo/io.github.pragha_music_player.metainfo.xml
%{_datadir}/pixmaps/%{name}/
%{_datadir}/pragha/
%{_mandir}/man?/*
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/libpragha.so

%files plugins
%license COPYING
%doc FAQ NEWS README
%dir %{_libdir}/%{name}/plugins/
%dir %{_libdir}/%{name}/plugins/*/
%{_libdir}/%{name}/plugins/*/*.plugin
%{_libdir}/%{name}/plugins/*/*.so*

%files plugins-devel
%license COPYING
%doc NEWS
%{_includedir}/libpragha
%{_libdir}/pkgconfig/libpragha.pc

%files lang -f %{name}.lang

%changelog
* Thu Feb  1 2024 Max Lin <mlin@suse.com>
- Fix build for Leap 15.6
  * Build with pkgconfig(gupnp-1.6) on 15.6
* Sat Sep 24 2022 Maurizio Galli <maurizio.galli@suse.com>
- Bump gupnp version requirement to fix Tumbleweed build
* Wed May 27 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Fix build for Leap 15.2
* Sun Nov 17 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Fix CPPFLAGS to use current versions.
- Fix the source URL.
* Sat Sep 28 2019 Stefan Seyfried <seife+obs@b1-systems.com>
- try to fix crazy deps explosion by packaging libpragha.so in main
  pragha package
- do not package plugins again in plugins-devel package
* Sun Aug 18 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.3.99.1 (1.4 RC)
  * Shows temporary messages or services errors such as
    in-app-notifications.
  * Replace the status bar with a floating bar that does not require
    so much space.
  * Huge refactoring of the mtp plugin. Everything runs in
    a second thread.
  * Split Pragha between the application and a library to link
    the plugins.
  * Add proxy setting to song-info plugin.
  * Introduce PraghaTempProvider but not used yet.
  * Move background tasks popover to main toolbar.
  * Strip accentuation and others characters when approximate search.
    Issue #146
  * Send notification when finished ampache or koel import
  * Use popovers in the menus of sidebars.
  * Improve metadata for appstream. Issue #152
  * Adjust copyright mentioning Consonance.
  * Convert the status bar to an floating bar.
  * Implement upgrade Koel and Ampache from library pane menu.
  * Ampache: Reports when the server is empty.
  * Save the list of suggestions with the original information.
  * Show and hide the status bar automatically.
  * Depends on xdt-csource instead of exo-csource to compile the menus.
  * Add option to ignore playback errors to continue with others songs.
  * Vizualizer: Not saturate particles so much but give them
    more dynamics.
  * Last.fm: Postpose update current song when a scrobble is pending.
    Improve issue #142
  * Tune.In: Find the first audio between all results.
  * Rename dbus and appstream ids to better reverse-DNS domain.
    Issue #117
  * Don't use deprecated g_type_class_add_private.
  * Port the status icon menu to GktBuilder/GMenu/GAction.
  * Port part of library pane to GtkBuilder/GMenu.
  * Fix a lot of deprecations messages.
  * Fix ghost row (null null), in the list of similar songs
  * Fix pulse indication in filter entry while search.
  * DLNA client.. Force load glr-dleyna plugin.
  * Various fixes to compile pragha with msys2
* Fri Jun 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Fixed dependency issue due to new gupnp version in Tumbleweed
- Removed conditionals for Leap < 15
* Fri Jan 18 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 1.3.99 (1.4 RC)
  * First implementation of Favorites as a playlist.
  * Sync favorites with Koel and Last.Fm.
  * New Visualizer plugin. Just thanks to Koel for the idea.
  * Use Alt+Return shortcut to edit the selected song.
  * Add progress indicator to the search entry while it works.
  * Remember last pane used on song info plugin.
  * Allows to customize the styles to the distro packagers.
  * Restore X11 session support. As fallback try to use dbus session manager.
  * Fix bad encoding on lastfm responses (gh#pragha-music-player/pragha#93)
  * Fix encoding on similar song panel.
  * Import Year from Koel if available.
  * Fix typo in autogen.sh. Thanks to acharjyanisankh.
  * Misc deprecation fixes and remove old code.
* Fri May 11 2018 lazy.kent@opensuse.org
- Update to 1.3.92 (1.4 beta3).
  * News:
    + Some improvements the recommendations panel.
  - New button to append all recommendations.
  - Can queue the songs with the Q key.
  * Bug Fixes:
    + Fix some memory leaks.
    + Fix some deprecation warnings. Issue #136.
    + Fix issue #139 "Similar songs" always shown.
    + Mitigate a lot of warnings introduced on pull request #131.
    + Ignore phones that are charging without mtp support.
    + Handle correctly when disconnect the phone cable.
  * Updated Translations: Arabic (new), Bulgarian, Danish, German,
    Catalan, Spanish, French, Indonesian, Korean, Polish,
    Portuguese, Portuguese (Brazil), Russian, Slovak, Chinese.
- Changes in 1.3.91.1.
  * News:
    + Save lyrics and artist bio ans similar songs in user cache as
    files.
  - These are easily editable by the user.
    + Implement increse play count to Koel.
    + Various improvements to the tag editor dialog.
  - Add a header that highlights the main tags.
  - Update the header as you edit the tags.
  - Hides the check buttons and shows them when the tag is
    modified.
  - When you demarcate the check, restore the original tag.
  * Bug Fixes:
    + Fix plugins on last tarball due to an internal development
    patch. Issue #135.
- Drop pragha-gtk_switch_set_state.patch: no need anymore.
- Remove BuildRequires: ImageMagick, autoconf, libtool, pkgconfig(grilo-0.2)
- Add BuildRequires: fdupes, rygel-devel, pkgconfig(grilo-0.3),
  pkgconfig(gupnp-1.0), pkgconfig(json-glib-1.0).
- Improve plugins description.
- Changes in 1.3.91.
  * News:
    + New Koel plugin that allow play music from this service.
    + Implements cache purge limited by size. 1GB by default.
    + Add option to "Add and Play" from library view.
    + Allows reordering the columns of the playlists.
    + New panel on info plugin that show recomendations from
    Lastfm.
  * Other Changes:
    + Use custom name for the panel icons. Issue #121.
    + Add a symbolic icon for panel. Not used by default.
    + Put cover arts cache to .cache/pragha/art.
    + Need Gtk >= 3.14.
    + Add "Search" hint to search entry.
  * Bug Fixes:
    + Fix Incorrect Can* properties of the MPRIS Specification.
    + Implement emit CanNext/Prev/Play/Pause/Seek. Issue #123.
    + Rename default playlist name from "Playlists" to "Tracks" on
    MPRIS2.
    + Fixes for Appstream Standard Conformance.
    + Add BUFFERING state to backend to allow stop on slow
    connections.
    + Fix some GtkDialog mapped without a transient parent.
    + Fix Build system can try to use grilo-0.2 and grilo-0.3
    simultaneously. Issue #124.
    + Fix double unref on Ampache and Koel plugins.
    + Fix easy to miss dependency on exo-csource. Issue #128.
    + Try to improve filter response.
    + Silently ignore utf8 errors from last.fm reponces. Issue #93.
    + Try to improve open files dialog.
- Changes in 1.3.90.
  * News:
    + New Ampache plugin.
    + Uses a new concept of 'provider' that allows show music from
    multiple collections independently.
    + New standard widget to display progress of long tasks.
  * Other Changes:
    + Allow apply a custom css. Related to Issue #64, #87.
    + Register session in GtkApplication now compatible with Xfce
    4.14.
    + Implement disconect device action to mtp plugin.
    + Add backward compatibility to grilo.
    + Use a .ui file to define menu button.
    + Remove custom invisible char of lastfm password.
    + Dist pragha.ico/.rc needed to msys build.
    + Fixes some border, spacing and margins.
  * Bug Fixes:
    + Use same accel to show second sidebar that gnome-builder.
    Issue #73.
    + Fix Menu icon blured preferring non symbolic icons. Issue
    [#85].
    + Fixing duration formatting. Issue #103.
    + Fix dnd over an empty place in the playlist. Issue #104.
    + Align to center the toolbar icons instead vertical fill.
    Issue #108.
    + Don't use keybinder plugin on wayland. Issue #118.
    + Fix a few of Gtk deprecations.
    + Misc fixes to Gtk 3.20 and GCC 6.0.
    + Valgrind: Fix a lot of memory leaks.
    + Fixed typo analized -> analyzed.
    + Fix spelling and grammar on README.
    + Consider all rows as fixed size. It is supposed to improve
    speed.
  * New Translations: Danish, Indonesian, Slovak.
    + A lot of updated translations.
* Sun Aug 21 2016 badshah400@gmail.com
- Do not use grilo BuildRequires for Leap 42.2, as it has grilo
  v0.13.
* Thu Apr  7 2016 lazy.kent@opensuse.org
- BuildRequires: pkgconfig(grilo-0.2) for oS <= 13.2. The program
  isn't ready for grilo-0.3 yet.
* Mon Jan 18 2016 kleinrob@mpip-mainz.mpg.de
- Add pragha-gtk_switch_set_state.patch: fix build for openSUSE
  13.1.
* Thu Oct  1 2015 lazy.kent@opensuse.org
- Update to 1.3.3.
  * Rework the interface of equalizer and adds the preamplifier.
  * Add a switch for disabling the equalizer preset easily.
  * Add option to use small icons on tool/headerbar.
  * Change "Use Gnome 3 HIG" option to "Use system title bar and
    borders".
  * Don't use icons on menubar.
  * Fixes undefined symbols of devices plugin.
  * Use uri instead filename to save playlist with TotemPlPlarser.
  * Add all songs when import online playlists.
  * Expand widgets if added as wide control.
  * New Lithuanian and Polish translation.
  * Update translations: French, German, Portuguese, Russian,
    Bulgarian, Swedish.
- Don't install ChangeLog (it is outdated).
- Add an rpmlintrc file.
* Sun Aug 16 2015 lazy.kent@opensuse.org
- Remove BuildRequires: rygel-devel because of hardcoded version,
  see gh#pragha-music-player/pragha#82.
* Sun Jun 21 2015 lazy.kent@opensuse.org
- Update to 1.3.2.2.
  * Fixed: Not save state album_art_in_osd=false.
  * Provide more app icons size.
  * Set expand comment entry on tag dialog.
  * Ensure menu size and fallback to 16 on library and playlist
    icons.
  * Updated translations: German, Ukrainian, Czech.
  * New Bulgarian translation.
- Correct the project URL.
- Doesn't buildrequires fdupes.
* Sun Feb 22 2015 lazy.kent@opensuse.org
- Update to 1.3.2.1.
  * Disable libtool versioning for plugins.
  * Not remember visibility of the second siderbar when init.
  * Fix icon size on preferences dialog on Gtk 3.14.
  * Try to fix the small progress bar on gtk 3.14, but finally just
    center it.
  * Disable popover on gear menu!. It is just horrible!!, and pior
    on 3.14.
  * Fix size of Gear menu.
  * Add Castillan translation to the install list.
  * Updates translations: Russian, Korean, French.
- Drop pragha-fix-plugin-linking.patch: fixed upstream.
* Tue Feb 17 2015 gber@opensuse.org
- Add pragha-fix-plugin-linking.patch in order to remove versioning
  and soname from plugins (gh#pragha-music-player/pragha#74)
- Enable compiler output
* Sat Jan 17 2015 lazy.kent@opensuse.org
- Update to 1.3.2.
  * Add optional client-side-decorators support trying to follow
    GNOME 3 HIG.
  * Can hide menubar and then append a gear menu on toolbar.
  * Add a infobar when some change on prefrences need restart.
  * Except activation of plugins must accept the preferences dialog
    for the changes to take effect.
  * A lot of margins and sizes were stylized to improve the design.
  * Acrivate mpris2 and show lyrics sidebar by default.
  * Devices plugin: Fix remove library and drop database when eject
    any usb mass storage.
  * Devices plugin: Show a message when fails to mount a usb.
  * Devices plugin: Properly handles devices that are mounted by
    the desktop before than by Pragha.
  * Devices plugin: Fix format not a string literal and no format
  * arguments [-Werror=format-security].
    Check existence of the files before import any playlist. So..
    never more import empty playlists.
  * Fix change library when old list is empty.
  * Insensitive some playback actions on toolbar, menubar and
    systray when startup.
  * Lastfm: Be a little more careful with PraghaMusicobject
    references.
  * Remove useless option to setting gstreamer version con
    configure.ac.
  * Remove preferences (including passwords) when plugins are
    deactivated.
  * Don't use deprecated GtkArrow.
  * New Castillan translation.
  * Update German, Czech, Portuguese, Russian, Korean, Spanish
    translations.
- Move Korean locale from ko_KR to ko.
- Correct the source URL.
* Sat Oct  4 2014 lazy.kent@opensuse.org
- Replace BuildRequires: pkgconfig(rygel-core-2.2),
  pkgconfig(rygel-server-2.2) with rygel-devel because they are
  versioned.
- Remove BuildRequires: appdata-tools; %%{_datadir}/appdata/ is
  owned by filesystem.
* Sun Aug  3 2014 lazy.kent@opensuse.org
- Update to 1.3.1.
  * New TuneIn plugin. Allow search on TuneIn and append first
    radio.
  * New DLNA server plugin. Allow share playlist to a DLNA server
    using Rygel.
  * New DLNA renderer plugin. Allow play music on a DLNA server
    using Grilo.
  * New AcousticId plugin. Get metadata of current song on AcoustID
    service.
  * Port to GtkApplication.
  * Return a basic support to MOD files.
  * Allow playback music on MTP devices.
  * The CD-ROM support became a plugin.
  * The Last.fm support became a plugin.
    + Better protect tags and time_t on threads.
    + Use diferents time_id to scrobble and update now playing.
    + Fix submits multiple entries of one song to LastFM.
    + Betters function names and declare a lot as static.
  * Song-info plugin: don't delay searching and cancel if song was
    changed.
  * Allow recursive playlist disabled.
  * Reduce track progress bar size. (A regresion since Gtk+-2).
  * Split Devices plugin. Devices, MTP, Removable, and CDROM.
  * PraghaMusicobject/Database: file_type coverted to mime_type.
  * PraghaMusicobject: Add source property, to differentiate local
    files, of http, or plugins.
  * GUI: Show Mimetype on Playlist and tags properties dialog.
  * Set <Control>O as acceletator to open files dialog.
  * Enable the Notify and Song Info plugins on first run.
  * Fix Segfault when edit song tags from systray menu.
  * Playlist: fix memory leak.
  * Fix compilation without libpeas.
  * Fix some segfault when use Glib >= 2.40.
  * Create cache folders when init it.
  * Show album arts in cache to all songs.
  * Not import empty playlists when scan the library.
  * Update the menubar and playlist submenu when change any
    playlists saved.
  * Fix never change album on playlist when update tags.
  * Fix bad update of title on playlist when update tags.
  * Notify Plugin: Remove custom timeout.
  * Notify plugin: Check new song before sending a notification.
  * Lastfm Plugin: Fix warning when user or password in empty.
  * Lastfm Plugin: No start new sessions every time that close the
    configuration dialog.
  * Add licence to xml_helper.c/.h files.
  * Fix opening folder with images.
  * Some improvements to English source file strings.
  * Update Chinese, Czech, French, Portuguese translation.
- Changes in 1.3.0.
  * Depends completely on Gtk+3 >= 3.2 and Glib >= 2.32, Gstreamer1
    and libcdio_paranoia >= 0.90.
  * Add support to plugins, depending on libpeas >= 1.2.
    + Port gnome-media-keys, keybinder, mpris2, notify, and
    song-info.
    + Still pending rewrite the lastfm plugin.
    + Add SOO-EXPERIMENTAL and INCOMPLET devices plugin.
  * Add a second sidebar on right.
    + Just used by the plugin song-info to show lyrics.
  * Continued with the cleaning, writing, and conversion to
  * GObjects
    + PraghaArtCache, PraghaSidebar, and every plugins.
    + PraghaApplication now is based on GtkApplication.
  * Fix many bugs in gtk+3 interface, and fixes deprecations prior
    3.10.
- Add/changes BuildRequires: appdata-tools (for oS > 13.2),
  pkgconfig(glib-2.0) >= 2.32, pkgconfig(grilo-0.2),
  pkgconfig(gtk+-3.0) >= 3.4.0, pkgconfig(gudev-1.0),
  pkgconfig(libcdio_paranoia) >= 0.90, pkgconfig(libmtp),
  pkgconfig(libpeas-1.0), pkgconfig(libpeas-gtk-1.0),
  pkgconfig(libsoup-2.4), pkgconfig(rygel-core-2.2),
  pkgconfig(rygel-server-2.2), pkgconfig(keybinder-3.0),
  pkgconfig(libxfce4ui-2).
- Split off -plugins subpackage and add it to Recommends.
- Build -plugins-devel subpackage.
- Correct URL.
* Sat Jul  5 2014 lazy.kent@opensuse.org
- Update to 1.2.2.
  * Fix some segfault when use Glib >= 2.40. (Change requirements
    to Glib >= 2.32).
  * Fix segfault when change preferences and mpris2 is disabled.
  * Fix segfault when close Pragha and Mpris2 is disabled.
- Add BuildRequires: pkgconfig(glib-2.0) >= 2.32.
* Wed Apr 30 2014 lazy.kent@opensuse.org
- Update to 1.2.1.
  * Create cache folders when init album-art-cache.
  * Lastfm: Backport some changes from Pragha 1.3.1.
    + Better protect tags and time_t on threads.
    + Use diferents time_id to scrobble and update now playing.
    + Fix submits multiple entries of one song to LastFM.
    + Betters function names and declare a lot as static.
  * Show album arts in cache to all songs. But search in folders
    only to local songs.
  * Fix Segfault when edit song tags from systray menu.
  * Not import empty playlists when scan the library.
* Sun Feb  9 2014 lazy.kent@opensuse.org
- Update to 1.2.
  * Highlight the headers on library view.
  * Disable all video features of playbin.
  * Add support for embedded album art.
  * Add simple appdata.xml to gnome-software.
  * Continued with the cleaning, writing, and conversion to
    GObjects.
    + PraghaToolbar, PraghaLibraryPane, PraghaPlaylist, etc.
    + PraghaApplication is based on GApplication, controlling
    single instance, and dbus messages.
  * All preferences have been ported to PraghaPreferences.
  * Require by default Gstreamer >= 1.0.
  * Fix unable to automatically play another song in pragha.
  * Art-cache: fix for case artist or album cointains slash.
  * Fix regression on 1.1.2: Return to import playlists.
  * Fix save fuse_folders option when not set folder structure
    view.
  * No insensitive albumart_in_osd toggle button when change show
    sytray option.
  * Fix wrong min glib version. g_thread_unref need 2.31.
  * Fix updating library view after rescan.
  * Dbus: fix crash on get current state.
  * Fix some coverity defects:
    + Unused pointer value (UNUSED_VALUE).
    + Uninitialized scalar variable (UNINIT).
    + Division or modulo by zero (DIVIDE_BY_ZERO).
    + Unchecked return value (CHECKED_RETURN).
    + Unchecked return value from library (CHECKED_RETURN).
    + Dereference before null check (REVERSE_INULL).
    + Resource leak (RESOURCE_LEAK).
    + Explicit null dereferenced (FORWARD_NULL).
  * Fix thread safety when reading tags.
  * Explicitly specified use normal fonts in the library.
  * Fix segfault when disable and enable again mpris2.
  * Add Korean and Vietnamese translations.
  * Many other updates.
- Drop pragha-1.0.2-pixdir.patch (keep as is).
- Drop pragha-1.1.2-russian.patch (fixed upstream).
- Change the source URL.
* Sun Mar 24 2013 dimstar@opensuse.org
- Switch to GStreamer 1.0:
  + Change pkgconfig(gstreamer-0.10*) BuildRequires to
    pkgconfig(gstreamer-1.0*).
  + Replace gstreamer-0_10-* Requires with gstreamer-*.
  + Pass --with-gstreamer=1.0 to configure.
* Thu Feb 21 2013 lazy.kent@opensuse.org
- Update to 1.1.2.
  * Improved indexing of the library. Also allows continue
    listening music while analyzing.
  * The database uses prepared statements, improving the general
    performance of Pragha.
  * A general cleaning of the code.
  * Now add, remove or rename playlist and radios is super fast.
  * Now select the content of the "Track No" and "Year" in "Edit
    tags" window after focusing or clicking into them.
  * Now you can drag songs from the library to any file manager to
    copy or burn with brasero.
  * Now you can add playlists using command line or file managers.
  * Save and restore menu accelerators edited.
  * Now whenever you add songs, select the first song added.
  * Bugs fixed:
    + glyr-related.c: Use lang autodetection to get artist bio
    + mpris: fix problems with long tracks
    + translations: fix plural forms
    + add workaround for crash in taglib
    + fix a deadlock on adding to current playlist
  * Updated translations.
- Change source URL.
- Update russian.patch.
- BuildRequires: pkgconfig(gthread-2.0) >= 2.32, intltool.
* Thu Aug 23 2012 lazy.kent@opensuse.org
- Update to 1.1.1.
  * Add a button to close the sidebar.
  * Use toolbar style to playback controls.
  * Add an option to hide the icon in the notification area.
  * Depend on gtk+2.24 and glib 2.28.
  * Modularization/Refactoring/Cleanup of a lot of code.
  * Support global hotkeys with keybinder and gtk3 if detect
    keybinder-3.0.
  * Various improvements in gstreamer.
  * Enable MusicBrainz to download cover art.
  * Sanitize artist and title when append from lastfm.
  * Fix equalizer dialog in gtk3 interface.
  * Fix tag dialog in gtk3 interface.
  * equalizer: fix GObject leak.
  * Not refresh the library view if the radio added is not saved.
  * Fix read after free. See Github issue #20.
  * Not forget the previous songs when queue songs.
  * Not forget the previous songs when play songs activating
    playlist.
  * Removes a lot of unused variables and functions.
  * Updates translations.
- Drop pragha-1.1.0.1-cover_musicbrainz.patch (fixed upstream).
- Build requires pkgconfig(gtk+-2.0) >= 2.24.
* Wed Jun 20 2012 lazy.kent@opensuse.org
- Add pragha-1.1.0.1-cover_musicbrainz.patch: also search covers in
  MusicBrainz (https://github.com/matiasdelellis/pragha/issues/28).
* Wed Jun 20 2012 lazy.kent@opensuse.org
- Add pragha-1.1.0.1-russian.patch: correct Russian translation.
* Wed Jun 20 2012 lazy.kent@opensuse.org
- Update to 1.1.0.1.
  * Bugs fixed:
    + Fix crash when try to crop playlist with accelerator.
    + GUI: take ownership of images in the right way.
    + Fix build on i586.
    + MPRIS: fix crash in Player.Seek.
    + MPRIS: don't use constants from libdbus.
  * Update German translation.
- Drop pragha-1.1.0-i586.patch (fixed upstream).
* Sat Jun 16 2012 lazy.kent@opensuse.org
- Update to 1.1.0.
  * Suggest import XDG_MUSIC_DIR to library on first start.
  * Merge playlist and radios on unique library view pane.
  * Add option to make aproximate searchs using a levenshtein
    distance.
  * Add a new menu option to copy tags of selection in current
    playlist.
  * mpris: partially implement AddTrack.
  * Add support for gstreamer 1.0.
  * F9 to show/hide the sidepane.
  * Add --log-file/ -l command line option to log debug to a file.
  * Follow fdo Icon Naming Specification.
  * Reorganization of the main menu.
    + File menu change to Playback and adds the random and repeat
    options.
    + Edit menu change to Playlist, and adds the options to add
    files, audio CD and locations.
    + Preferences are now found in tools.
  * The initial window size and cols width is set dynamically
    according to the screen size.
  * Fixed bugs (see NEWS file).
- Add pragha-1.1.0-i586.patch: fix build in i586
  (https://github.com/matiasdelellis/pragha/issues/31).
* Sat May 26 2012 lazy.kent@opensuse.org
- BuildRequires: pkgconfig(libcdio_paranoia).
* Thu May  3 2012 lazy.kent@opensuse.org
- Update to 1.0.2.
  * Use totem-pl-parser to open playlists when is available.
    + With this can open internet radios playlist.
    + Supports many more formats.
  * Imports playlists when update the library.
  * Use libxfce4ui instead of libexo-1 to session management.
  * In/Sensitive menus according playback and lastfm status.
  * Allow displaying length and progress of remote files.
  * Fixed bugs (see NEWS file).
  * Updated translations.
- Dropped "optflags", "desktop", "russian" patches (fixed
  upstream).
- Updated "pixdir" patch.
* Tue Mar 13 2012 lazy.kent@opensuse.org
- Update to 1.0.1.
  * Added Get lyrics, Get artist info to the selection on current
    playlist.
  * Added Love, Unlove, and Get similar options to the selection on
    current playlist.
  * Add an icon in the panel to suggest tag corrections of lastfm
    when update now_playing.
  * Added tootips to show equalizer bands values.
  * Select last track when append new songs.
  * Also append radios when restore session.
  * Append Hz, kbps, and Channels string to file properties dialog.
  * Check status of network manager when launch pragha. If is
    online, init lastfm, otherwise wait 30 seconds.
  * Removed search album art option in menu.
  * Only search covers art in lastfm temporarily. Returns better
    results.
  * Updated translations: German, Portuguese, Italian, Russian.
  * A lot of bugs fixed (see NEWS).
- Depends on libclastfm >= 0.5.
- Updated "russian" patch.
* Fri Feb  3 2012 lazy.kent@opensuse.org
- Patch to update Russian translation.
* Fri Feb  3 2012 lazy.kent@opensuse.org
- Added GStreamer plugins to dependencies.
* Thu Feb  2 2012 lazy.kent@opensuse.org
- Update to 1.0.
  * Add a classic 10-band software equalizer.
  * Save the m3u playlists with relative paths when stored in the
    same directory that the audio files.
  * Bugs fixed:
    + Emit album art URL on MPRIS2 when is available.
    + Emit new metadata when edit tag of current track.
    + Fix try to edit some tags of radio stream with taglib.
    + Add playlists mime on desktop file.
    + Use autoaudiosink as default audiosink.
    + Update notifications instead of show one for each song
    change.
    + Set Next as default button when show a playback error.
    + Do not allow change song from mpris/keybinder/systray when
    show a playback error.
    + Can open playlists with relative paths.
    + Save radio stream when press enter on name.
    + Fix compilation without exo-1.
    + Confirm with an dialog before delete any radio/playlist item.
    + Fixes some memory leaks.
  * Added Italian translation.
  * Updated German, Portuguese, Russian translations.
- Patch to remove Unity shortcuts from desktop file (lp#789867).
- Split off language package.
* Mon Dec 19 2011 lazy.kent@opensuse.org
- Patch to use default openSUSE optimization flags.
- Add autoconf as buildrequire.
* Thu Dec 15 2011 lazy.kent@opensuse.org
- Initial package created - 0.99.3 (1.0.RC3).
- Patch to fix pixmaps directory.
